// pages/login/login.js
import WxValidate from '../../utils/wxValidate'
const app = getApp()
Page({
    /**
     * 页面的初始数据
     */
    data: {
        // 主体高度
        infoHeight: '',
        frameStyle: { useTop: true, name: '个人信息', leftArrow: true, useBar: false },
        form: {},
        fileList: [],
        genderList: [{ id: '0', name: '男' }, { id: 1, name: '女' },],
        index: 0,
    },
    //验证必填项
    initValidate() {
        const rules = { phone: { required: true, tel: true }, }
        // 验证字段的提示信息，若不传则调用默认的信息
        const messages = { phone: { required: '请输入手机号' }, };
        this.WxValidate = new WxValidate(rules, messages)
    },
    back: function () {
        wx.navigateBack({ url: '/pages/me/index' })
    },
    //上传图片
    imgUpload: function (e) {
        const that = this;
        let data = that.data.fileList;
        data.push(e.detail)
        that.setData({ fileList: data })
    },
    //删除图片
    imgDel: function (e) {
        const that = this;
        let data = that.data.fileList;
        let arr = data.filter((i, index) => index != e.detail.index)
        that.setData({ fileList: arr })
    },
    // 选择用户性别
    bindPickerChange: function (e) {
        const that = this;
        let index = e.detail.value;
        let data = that.data.genderList[index];
        if (data) that.setData({ 'form.gender': data.name });
    },
    //提交
    formSubmit: function (e) {
        const value = e.detail.value;
        if (!this.WxValidate.checkForm(value)) {
            const error = this.WxValidate.errorList[0];
            wx.showToast({ title: `${error.msg}`, icon: 'error', duration: 2000 })
            return false
        } else {
            value.icon = this.data.fileList;
            value.id = this.data.form.id;
            wx.request({
                url: `${app.globalData.publicUrl}/courtAdmin/api/user/${value.id}`, //接口地址
                method: "post",
                data: value,
                header: {},
                success: res => {
                    if (res.data.errcode == 0) {
                        wx.showToast({
                            title: '保存成功',
                            icon: 'success',
                            duration: 2000//延迟两秒
                        })
                    } else {
                        wx.showToast({
                            title: '保存失败',
                            icon: 'success',
                            duration: 2000
                        })
                    }
                },
            })
        }
    },
    /**
     * 生命周期函数--监听页面加载
     */
    onLoad: function (options) {
        //验证规则函数
        this.initValidate();
        // 计算高度
        this.searchHeight();
        // 监听用户是否登录
        this.watchLogin();
    },
    // 计算高度
    searchHeight: function () {
        let frameStyle = this.data.frameStyle;
        let client = app.globalData.client;
        let infoHeight = client.windowHeight;
        // 是否去掉状态栏
        if (frameStyle.useTop) infoHeight = infoHeight - (client.statusBarHeight + client.getMenu.height + (client.getMenu.top - client.statusBarHeight) * 2);
        // 是否减去底部菜单
        if (frameStyle.useBar) infoHeight = infoHeight - 50;
        if (infoHeight) this.setData({ infoHeight: infoHeight })
    },
    // 监听用户是否登录
    watchLogin: function () {
        const that = this;
        wx.getStorage({
            key: 'token',
            success: res => {
                //数据请求
                wx.request({
                    url: `${app.globalData.publicUrl}/courtAdmin/api/user/${res.data.id}`, //接口地址
                    method: "get",
                    data: {},
                    header: {},
                    success: res => {
                        that.setData({ form: res.data.data })
                        let icon = res.data.data.icon;
                        that.setData({ fileList: icon })
                    },
                    error: err => {
                    }
                })
            },
            fail: res => {
                wx.redirectTo({ url: '/pages/login/index', })
            }
        })
    },
    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady: function () {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide: function () {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload: function () {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh: function () {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom: function () {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage: function () {

    }
})